/**
 * OW2 Util
 * Copyright (C) 2010-2011 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Activator.java 5690 2011-01-05 20:34:57Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.protocol.osgi.impl;

import java.util.Properties;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.protocol.api.IProtocol;
import org.ow2.util.protocol.api.IProtocolConfigRegistry;
import org.ow2.util.protocol.api.IShellFormatter;
import org.ow2.util.protocol.impl.ProcessProtocol;
import org.ow2.util.protocol.impl.ProtocolConfigRegistryImpl;
import org.ow2.util.protocol.impl.shell.MsDosShellFormatter;
import org.ow2.util.protocol.impl.shell.ShShellFormatter;
import org.ow2.util.protocol.osgi.api.Constants;

/**
 *
 * @author Loris Bouzonnet
 */
public class Activator implements BundleActivator {

    private ServiceRegistration processReg;

    private ServiceRegistration shReg;

    private ServiceRegistration msDosReg;

    private ServiceRegistration registryReg;

    public void start(final BundleContext context) throws Exception {

        final Properties processProps = new Properties();
        processProps.put(Constants.PROTOCOL_NAME, Constants.PROCESS_PROTOCOL);
        processReg = context.registerService(IProtocol.class.getName(), new ProcessProtocol(), processProps);

        final ShShellFormatter shFormatter = new ShShellFormatter();
        final Properties shProps = new Properties();
        shProps.put(Constants.SHELL_TYPE, "sh");
        shReg = context.registerService(IShellFormatter.class.getName(), shFormatter, shProps);

        final MsDosShellFormatter msDosFormatter = new MsDosShellFormatter();
        final Properties msDosProps = new Properties();
        msDosProps.put(Constants.SHELL_TYPE, "msdos");
        msDosReg = context.registerService(IShellFormatter.class.getName(), msDosFormatter, msDosProps);

        final ProtocolConfigRegistryImpl configRegistry = new ProtocolConfigRegistryImpl();
        registryReg = context.registerService(IProtocolConfigRegistry.class.getName(), configRegistry, null);

    }

    public void stop(final BundleContext context) throws Exception {

        if (processReg != null) {
            processReg.unregister();
        }
        if (shReg != null) {
            shReg.unregister();
        }
        if (msDosReg != null) {
            msDosReg.unregister();
        }
        if (registryReg != null) {
            registryReg.unregister();
        }
    }

}
